==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/record/vo/RecordestsumdetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计概算汇总变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordestsumdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long recordMid; // 设计概算汇总变更记录主表id
    private java.lang.String sort; // 序号
    private java.lang.String inventoryCode; // 清单编码
    private java.lang.String engineeringName; // 工程名称或费用名称
    private java.math.BigDecimal engineeringScale; // 设计规模或者主要工程量
    private java.math.BigDecimal engineering; // 建筑工程费
    private java.math.BigDecimal purchase; // 安装购置费
    private java.math.BigDecimal installEngineering; // 安装工程
    private java.math.BigDecimal total; // 合计
    private java.lang.String memo; // 备注
    

    /**
     * 设计概算汇总变更记录主表id
     */
    public java.lang.Long getRecordMid() {
        return recordMid;
    }

    /**
     * 设计概算汇总变更记录主表id
     */
    public void setRecordMid(java.lang.Long recordMid) {
        this.recordMid = recordMid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getInventoryCode() {
        return inventoryCode;
    }

    /**
     * 清单编码
     */
    public void setInventoryCode(java.lang.String inventoryCode) {
        this.inventoryCode = inventoryCode;
    }
    /**
     * 工程名称或费用名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称或费用名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 设计规模或者主要工程量
     */
    public java.math.BigDecimal getEngineeringScale() {
        return engineeringScale;
    }

    /**
     * 设计规模或者主要工程量
     */
    public void setEngineeringScale(java.math.BigDecimal engineeringScale) {
        this.engineeringScale = engineeringScale;
    }
    /**
     * 建筑工程费
     */
    public java.math.BigDecimal getEngineering() {
        return engineering;
    }

    /**
     * 建筑工程费
     */
    public void setEngineering(java.math.BigDecimal engineering) {
        this.engineering = engineering;
    }
    /**
     * 安装购置费
     */
    public java.math.BigDecimal getPurchase() {
        return purchase;
    }

    /**
     * 安装购置费
     */
    public void setPurchase(java.math.BigDecimal purchase) {
        this.purchase = purchase;
    }
    /**
     * 安装工程
     */
    public java.math.BigDecimal getInstallEngineering() {
        return installEngineering;
    }

    /**
     * 安装工程
     */
    public void setInstallEngineering(java.math.BigDecimal installEngineering) {
        this.installEngineering = installEngineering;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20240528.015635-206-sources.jar: com/ejianc/business/record/vo/RecordestsumdetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.bedget.vo.EstimatesummarydetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计概算汇总变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordestsumdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long recordMid; // 设计概算汇总变更记录主表id
    private java.lang.Long originalId; // 原始单据id（设计概算汇总子表）
    private java.lang.String sort; // 序号
    private java.lang.String inventoryCode; // 清单编码
    private java.lang.String engineeringName; // 工程名称或费用名称
    private java.math.BigDecimal engineeringScale; // 设计规模或者主要工程量
    private java.math.BigDecimal engineering; // 建筑工程费
    private java.math.BigDecimal purchase; // 安装购置费
    private java.math.BigDecimal installEngineering; // 安装工程
    private java.math.BigDecimal total; // 合计
    private java.lang.String memo; // 备注
    private java.lang.String tid;
    private java.lang.String tpid;

    private List<RecordestsumdetailVO> children = new ArrayList<>();

    public List<RecordestsumdetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<RecordestsumdetailVO> children) {
        this.children = children;
    }
    

    /**
     * 设计概算汇总变更记录主表id
     */
    public java.lang.Long getRecordMid() {
        return recordMid;
    }

    /**
     * 设计概算汇总变更记录主表id
     */
    public void setRecordMid(java.lang.Long recordMid) {
        this.recordMid = recordMid;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getInventoryCode() {
        return inventoryCode;
    }

    /**
     * 清单编码
     */
    public void setInventoryCode(java.lang.String inventoryCode) {
        this.inventoryCode = inventoryCode;
    }
    /**
     * 工程名称或费用名称
     */
    public java.lang.String getEngineeringName() {
        return engineeringName;
    }

    /**
     * 工程名称或费用名称
     */
    public void setEngineeringName(java.lang.String engineeringName) {
        this.engineeringName = engineeringName;
    }
    /**
     * 设计规模或者主要工程量
     */
    public java.math.BigDecimal getEngineeringScale() {
        return engineeringScale;
    }

    /**
     * 设计规模或者主要工程量
     */
    public void setEngineeringScale(java.math.BigDecimal engineeringScale) {
        this.engineeringScale = engineeringScale;
    }
    /**
     * 建筑工程费
     */
    public java.math.BigDecimal getEngineering() {
        return engineering;
    }

    /**
     * 建筑工程费
     */
    public void setEngineering(java.math.BigDecimal engineering) {
        this.engineering = engineering;
    }
    /**
     * 安装购置费
     */
    public java.math.BigDecimal getPurchase() {
        return purchase;
    }

    /**
     * 安装购置费
     */
    public void setPurchase(java.math.BigDecimal purchase) {
        this.purchase = purchase;
    }
    /**
     * 安装工程
     */
    public java.math.BigDecimal getInstallEngineering() {
        return installEngineering;
    }

    /**
     * 安装工程
     */
    public void setInstallEngineering(java.math.BigDecimal installEngineering) {
        this.installEngineering = installEngineering;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
}
